# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/smartwebsecurity/v1/security_profile.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7yandex/cloud/smartwebsecurity/v1/security_profile.proto\x12 yandex.cloud.smartwebsecurity.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xb9\x05\n\x0fSecurityProfile\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x8a\x01\n\x06labels\x18\x03 \x03(\x0b\x32=.yandex.cloud.smartwebsecurity.v1.SecurityProfile.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x38\n\x04name\x18\x04 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\x1a[a-zA-Z0-9][a-zA-Z0-9-_.]*\x8a\xc8\x31\x04\x31-50\x12\x1e\n\x0b\x64\x65scription\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=512\x12]\n\x0e\x64\x65\x66\x61ult_action\x18\x06 \x01(\x0e\x32?.yandex.cloud.smartwebsecurity.v1.SecurityProfile.DefaultActionB\x04\xe8\xc7\x31\x01\x12\x46\n\x0esecurity_rules\x18\x07 \x03(\x0b\x32..yandex.cloud.smartwebsecurity.v1.SecurityRule\x12.\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x63loud_id\x18\n \x01(\t\x12\x12\n\ncaptcha_id\x18\x0b \x01(\t\x12(\n advanced_rate_limiter_profile_id\x18\x0c \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"D\n\rDefaultAction\x12\x1e\n\x1a\x44\x45\x46\x41ULT_ACTION_UNSPECIFIED\x10\x00\x12\t\n\x05\x41LLOW\x10\x01\x12\x08\n\x04\x44\x45NY\x10\x02J\x04\x08\t\x10\n\"\xb6\x08\n\x0cSecurityRule\x12\x38\n\x04name\x18\x01 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\x1a[a-zA-Z0-9][a-zA-Z0-9-_.]*\x8a\xc8\x31\x04\x31-50\x12\x1e\n\x08priority\x18\x02 \x01(\x03\x42\x0c\xfa\xc7\x31\x08\x31-999999\x12\x0f\n\x07\x64ry_run\x18\x03 \x01(\x08\x12V\n\x0erule_condition\x18\x04 \x01(\x0b\x32<.yandex.cloud.smartwebsecurity.v1.SecurityRule.RuleConditionH\x00\x12Z\n\x10smart_protection\x18\x05 \x01(\x0b\x32>.yandex.cloud.smartwebsecurity.v1.SecurityRule.SmartProtectionH\x00\x12\x41\n\x03waf\x18\x06 \x01(\x0b\x32\x32.yandex.cloud.smartwebsecurity.v1.SecurityRule.WafH\x00\x12\x1e\n\x0b\x64\x65scription\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=512\x1a\xdb\x01\n\rRuleCondition\x12S\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x43.yandex.cloud.smartwebsecurity.v1.SecurityRule.RuleCondition.Action\x12>\n\tcondition\x18\x02 \x01(\x0b\x32+.yandex.cloud.smartwebsecurity.v1.Condition\"5\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\t\n\x05\x41LLOW\x10\x01\x12\x08\n\x04\x44\x45NY\x10\x02\x1a\xd5\x01\n\x0fSmartProtection\x12Q\n\x04mode\x18\x01 \x01(\x0e\x32\x43.yandex.cloud.smartwebsecurity.v1.SecurityRule.SmartProtection.Mode\x12>\n\tcondition\x18\x02 \x01(\x0b\x32+.yandex.cloud.smartwebsecurity.v1.Condition\"/\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x12\x07\n\x03\x41PI\x10\x02\x1a\xdb\x01\n\x03Waf\x12\x45\n\x04mode\x18\x01 \x01(\x0e\x32\x37.yandex.cloud.smartwebsecurity.v1.SecurityRule.Waf.Mode\x12>\n\tcondition\x18\x02 \x01(\x0b\x32+.yandex.cloud.smartwebsecurity.v1.Condition\x12\x1c\n\x0ewaf_profile_id\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\"/\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x12\x07\n\x03\x41PI\x10\x02\x42\x10\n\x0erule_specifier\"\xf9\r\n\tCondition\x12O\n\tauthority\x18\x01 \x01(\x0b\x32<.yandex.cloud.smartwebsecurity.v1.Condition.AuthorityMatcher\x12R\n\x0bhttp_method\x18\x02 \x01(\x0b\x32=.yandex.cloud.smartwebsecurity.v1.Condition.HttpMethodMatcher\x12R\n\x0brequest_uri\x18\x03 \x01(\x0b\x32=.yandex.cloud.smartwebsecurity.v1.Condition.RequestUriMatcher\x12T\n\x07headers\x18\x04 \x03(\x0b\x32\x39.yandex.cloud.smartwebsecurity.v1.Condition.HeaderMatcherB\x08\x82\xc8\x31\x04<=20\x12H\n\tsource_ip\x18\x05 \x01(\x0b\x32\x35.yandex.cloud.smartwebsecurity.v1.Condition.IpMatcher\x1a\xfc\x01\n\rStringMatcher\x12 \n\x0b\x65xact_match\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12$\n\x0f\x65xact_not_match\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12!\n\x0cprefix_match\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12%\n\x10prefix_not_match\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12%\n\x10pire_regex_match\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12)\n\x14pire_regex_not_match\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x42\x07\n\x05match\x1an\n\x11HttpMethodMatcher\x12Y\n\x0chttp_methods\x18\x01 \x03(\x0b\x32\x39.yandex.cloud.smartwebsecurity.v1.Condition.StringMatcherB\x08\x82\xc8\x31\x04<=20\x1al\n\x10\x41uthorityMatcher\x12X\n\x0b\x61uthorities\x18\x01 \x03(\x0b\x32\x39.yandex.cloud.smartwebsecurity.v1.Condition.StringMatcherB\x08\x82\xc8\x31\x04<=20\x1a\xb1\x01\n\x11RequestUriMatcher\x12G\n\x04path\x18\x01 \x01(\x0b\x32\x39.yandex.cloud.smartwebsecurity.v1.Condition.StringMatcher\x12S\n\x07queries\x18\x02 \x03(\x0b\x32\x38.yandex.cloud.smartwebsecurity.v1.Condition.QueryMatcherB\x08\x82\xc8\x31\x04<=20\x1az\n\x0cQueryMatcher\x12\x1a\n\x03key\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x31-255\x12N\n\x05value\x18\x02 \x01(\x0b\x32\x39.yandex.cloud.smartwebsecurity.v1.Condition.StringMatcherB\x04\xe8\xc7\x31\x01\x1a|\n\rHeaderMatcher\x12\x1b\n\x04name\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x31-255\x12N\n\x05value\x18\x02 \x01(\x0b\x32\x39.yandex.cloud.smartwebsecurity.v1.Condition.StringMatcherB\x04\xe8\xc7\x31\x01\x1a\xdf\x02\n\tIpMatcher\x12T\n\x0fip_ranges_match\x18\x01 \x01(\x0b\x32;.yandex.cloud.smartwebsecurity.v1.Condition.IpRangesMatcher\x12X\n\x13ip_ranges_not_match\x18\x02 \x01(\x0b\x32;.yandex.cloud.smartwebsecurity.v1.Condition.IpRangesMatcher\x12N\n\x0cgeo_ip_match\x18\x03 \x01(\x0b\x32\x38.yandex.cloud.smartwebsecurity.v1.Condition.GeoIpMatcher\x12R\n\x10geo_ip_not_match\x18\x04 \x01(\x0b\x32\x38.yandex.cloud.smartwebsecurity.v1.Condition.GeoIpMatcher\x1a\x31\n\x0fIpRangesMatcher\x12\x1e\n\tip_ranges\x18\x01 \x03(\tB\x0b\x82\xc8\x31\x07<=10000\x1a\x33\n\x0cGeoIpMatcher\x12#\n\tlocations\x18\x01 \x03(\tB\x10\x82\xc8\x31\x03>=1\x8a\xc8\x31\x01\x32\x90\xc8\x31\x01\x42}\n$yandex.cloud.api.smartwebsecurity.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1;smartwebsecurityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.smartwebsecurity.v1.security_profile_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$yandex.cloud.api.smartwebsecurity.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1;smartwebsecurity'
  _SECURITYPROFILE_LABELSENTRY._options = None
  _SECURITYPROFILE_LABELSENTRY._serialized_options = b'8\001'
  _SECURITYPROFILE.fields_by_name['labels']._options = None
  _SECURITYPROFILE.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _SECURITYPROFILE.fields_by_name['name']._options = None
  _SECURITYPROFILE.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\032[a-zA-Z0-9][a-zA-Z0-9-_.]*\212\3101\0041-50'
  _SECURITYPROFILE.fields_by_name['description']._options = None
  _SECURITYPROFILE.fields_by_name['description']._serialized_options = b'\212\3101\005<=512'
  _SECURITYPROFILE.fields_by_name['default_action']._options = None
  _SECURITYPROFILE.fields_by_name['default_action']._serialized_options = b'\350\3071\001'
  _SECURITYRULE_WAF.fields_by_name['waf_profile_id']._options = None
  _SECURITYRULE_WAF.fields_by_name['waf_profile_id']._serialized_options = b'\350\3071\001'
  _SECURITYRULE.fields_by_name['name']._options = None
  _SECURITYRULE.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\032[a-zA-Z0-9][a-zA-Z0-9-_.]*\212\3101\0041-50'
  _SECURITYRULE.fields_by_name['priority']._options = None
  _SECURITYRULE.fields_by_name['priority']._serialized_options = b'\372\3071\0101-999999'
  _SECURITYRULE.fields_by_name['description']._options = None
  _SECURITYRULE.fields_by_name['description']._serialized_options = b'\212\3101\005<=512'
  _CONDITION_STRINGMATCHER.fields_by_name['exact_match']._options = None
  _CONDITION_STRINGMATCHER.fields_by_name['exact_match']._serialized_options = b'\212\3101\0050-255'
  _CONDITION_STRINGMATCHER.fields_by_name['exact_not_match']._options = None
  _CONDITION_STRINGMATCHER.fields_by_name['exact_not_match']._serialized_options = b'\212\3101\0050-255'
  _CONDITION_STRINGMATCHER.fields_by_name['prefix_match']._options = None
  _CONDITION_STRINGMATCHER.fields_by_name['prefix_match']._serialized_options = b'\212\3101\0050-255'
  _CONDITION_STRINGMATCHER.fields_by_name['prefix_not_match']._options = None
  _CONDITION_STRINGMATCHER.fields_by_name['prefix_not_match']._serialized_options = b'\212\3101\0050-255'
  _CONDITION_STRINGMATCHER.fields_by_name['pire_regex_match']._options = None
  _CONDITION_STRINGMATCHER.fields_by_name['pire_regex_match']._serialized_options = b'\212\3101\0050-255'
  _CONDITION_STRINGMATCHER.fields_by_name['pire_regex_not_match']._options = None
  _CONDITION_STRINGMATCHER.fields_by_name['pire_regex_not_match']._serialized_options = b'\212\3101\0050-255'
  _CONDITION_HTTPMETHODMATCHER.fields_by_name['http_methods']._options = None
  _CONDITION_HTTPMETHODMATCHER.fields_by_name['http_methods']._serialized_options = b'\202\3101\004<=20'
  _CONDITION_AUTHORITYMATCHER.fields_by_name['authorities']._options = None
  _CONDITION_AUTHORITYMATCHER.fields_by_name['authorities']._serialized_options = b'\202\3101\004<=20'
  _CONDITION_REQUESTURIMATCHER.fields_by_name['queries']._options = None
  _CONDITION_REQUESTURIMATCHER.fields_by_name['queries']._serialized_options = b'\202\3101\004<=20'
  _CONDITION_QUERYMATCHER.fields_by_name['key']._options = None
  _CONDITION_QUERYMATCHER.fields_by_name['key']._serialized_options = b'\350\3071\001\212\3101\0051-255'
  _CONDITION_QUERYMATCHER.fields_by_name['value']._options = None
  _CONDITION_QUERYMATCHER.fields_by_name['value']._serialized_options = b'\350\3071\001'
  _CONDITION_HEADERMATCHER.fields_by_name['name']._options = None
  _CONDITION_HEADERMATCHER.fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\0051-255'
  _CONDITION_HEADERMATCHER.fields_by_name['value']._options = None
  _CONDITION_HEADERMATCHER.fields_by_name['value']._serialized_options = b'\350\3071\001'
  _CONDITION_IPRANGESMATCHER.fields_by_name['ip_ranges']._options = None
  _CONDITION_IPRANGESMATCHER.fields_by_name['ip_ranges']._serialized_options = b'\202\3101\007<=10000'
  _CONDITION_GEOIPMATCHER.fields_by_name['locations']._options = None
  _CONDITION_GEOIPMATCHER.fields_by_name['locations']._serialized_options = b'\202\3101\003>=1\212\3101\0012\220\3101\001'
  _CONDITION.fields_by_name['headers']._options = None
  _CONDITION.fields_by_name['headers']._serialized_options = b'\202\3101\004<=20'
  _globals['_SECURITYPROFILE']._serialized_start=158
  _globals['_SECURITYPROFILE']._serialized_end=855
  _globals['_SECURITYPROFILE_LABELSENTRY']._serialized_start=734
  _globals['_SECURITYPROFILE_LABELSENTRY']._serialized_end=779
  _globals['_SECURITYPROFILE_DEFAULTACTION']._serialized_start=781
  _globals['_SECURITYPROFILE_DEFAULTACTION']._serialized_end=849
  _globals['_SECURITYRULE']._serialized_start=858
  _globals['_SECURITYRULE']._serialized_end=1936
  _globals['_SECURITYRULE_RULECONDITION']._serialized_start=1261
  _globals['_SECURITYRULE_RULECONDITION']._serialized_end=1480
  _globals['_SECURITYRULE_RULECONDITION_ACTION']._serialized_start=1427
  _globals['_SECURITYRULE_RULECONDITION_ACTION']._serialized_end=1480
  _globals['_SECURITYRULE_SMARTPROTECTION']._serialized_start=1483
  _globals['_SECURITYRULE_SMARTPROTECTION']._serialized_end=1696
  _globals['_SECURITYRULE_SMARTPROTECTION_MODE']._serialized_start=1649
  _globals['_SECURITYRULE_SMARTPROTECTION_MODE']._serialized_end=1696
  _globals['_SECURITYRULE_WAF']._serialized_start=1699
  _globals['_SECURITYRULE_WAF']._serialized_end=1918
  _globals['_SECURITYRULE_WAF_MODE']._serialized_start=1649
  _globals['_SECURITYRULE_WAF_MODE']._serialized_end=1696
  _globals['_CONDITION']._serialized_start=1939
  _globals['_CONDITION']._serialized_end=3724
  _globals['_CONDITION_STRINGMATCHER']._serialized_start=2362
  _globals['_CONDITION_STRINGMATCHER']._serialized_end=2614
  _globals['_CONDITION_HTTPMETHODMATCHER']._serialized_start=2616
  _globals['_CONDITION_HTTPMETHODMATCHER']._serialized_end=2726
  _globals['_CONDITION_AUTHORITYMATCHER']._serialized_start=2728
  _globals['_CONDITION_AUTHORITYMATCHER']._serialized_end=2836
  _globals['_CONDITION_REQUESTURIMATCHER']._serialized_start=2839
  _globals['_CONDITION_REQUESTURIMATCHER']._serialized_end=3016
  _globals['_CONDITION_QUERYMATCHER']._serialized_start=3018
  _globals['_CONDITION_QUERYMATCHER']._serialized_end=3140
  _globals['_CONDITION_HEADERMATCHER']._serialized_start=3142
  _globals['_CONDITION_HEADERMATCHER']._serialized_end=3266
  _globals['_CONDITION_IPMATCHER']._serialized_start=3269
  _globals['_CONDITION_IPMATCHER']._serialized_end=3620
  _globals['_CONDITION_IPRANGESMATCHER']._serialized_start=3622
  _globals['_CONDITION_IPRANGESMATCHER']._serialized_end=3671
  _globals['_CONDITION_GEOIPMATCHER']._serialized_start=3673
  _globals['_CONDITION_GEOIPMATCHER']._serialized_end=3724
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ExpirationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ExpirationPolicy:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ExpirationPolicyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ExpirationConfig._ExpirationPolicy.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        EXPIRATION_POLICY_UNSPECIFIED: ExpirationConfig._ExpirationPolicy.ValueType  # 0
        STATIC: ExpirationConfig._ExpirationPolicy.ValueType  # 1
        SINCE_LAST_ACTIVE: ExpirationConfig._ExpirationPolicy.ValueType  # 2

    class ExpirationPolicy(_ExpirationPolicy, metaclass=_ExpirationPolicyEnumTypeWrapper): ...
    EXPIRATION_POLICY_UNSPECIFIED: ExpirationConfig.ExpirationPolicy.ValueType  # 0
    STATIC: ExpirationConfig.ExpirationPolicy.ValueType  # 1
    SINCE_LAST_ACTIVE: ExpirationConfig.ExpirationPolicy.ValueType  # 2

    EXPIRATION_POLICY_FIELD_NUMBER: builtins.int
    TTL_DAYS_FIELD_NUMBER: builtins.int
    expiration_policy: global___ExpirationConfig.ExpirationPolicy.ValueType
    ttl_days: builtins.int
    def __init__(
        self,
        *,
        expiration_policy: global___ExpirationConfig.ExpirationPolicy.ValueType = ...,
        ttl_days: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["expiration_policy", b"expiration_policy", "ttl_days", b"ttl_days"]) -> None: ...

global___ExpirationConfig = ExpirationConfig

@typing.final
class Error(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    code: builtins.int
    message: builtins.str
    def __init__(
        self,
        *,
        code: builtins.int = ...,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["code", b"code", "message", b"message"]) -> None: ...

global___Error = Error



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ValidationContext(google.protobuf.message.Message):
    """A TLS validation context resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRUSTED_CA_ID_FIELD_NUMBER: builtins.int
    TRUSTED_CA_BYTES_FIELD_NUMBER: builtins.int
    trusted_ca_id: builtins.str
    trusted_ca_bytes: builtins.str
    """X.509 certificate contents in PEM format."""
    def __init__(
        self,
        *,
        trusted_ca_id: builtins.str = ...,
        trusted_ca_bytes: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["trusted_ca", b"trusted_ca", "trusted_ca_bytes", b"trusted_ca_bytes", "trusted_ca_id", b"trusted_ca_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["trusted_ca", b"trusted_ca", "trusted_ca_bytes", b"trusted_ca_bytes", "trusted_ca_id", b"trusted_ca_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["trusted_ca", b"trusted_ca"]) -> typing.Literal["trusted_ca_id", "trusted_ca_bytes"] | None: ...

global___ValidationContext = ValidationContext



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.assistants.v1.runs.run_pb2
import yandex.cloud.ai.assistants.v1.runs.run_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class RunServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.CreateRunRequest,
        yandex.cloud.ai.assistants.v1.runs.run_pb2.Run,
    ]

    Listen: grpc.UnaryStreamMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListenRunRequest,
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.StreamEvent,
    ]

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.GetRunRequest,
        yandex.cloud.ai.assistants.v1.runs.run_pb2.Run,
    ]

    GetLastByThread: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.GetLastRunByThreadRequest,
        yandex.cloud.ai.assistants.v1.runs.run_pb2.Run,
    ]

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListRunsRequest,
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListRunsResponse,
    ]

class RunServiceAsyncStub:
    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.CreateRunRequest,
        yandex.cloud.ai.assistants.v1.runs.run_pb2.Run,
    ]

    Listen: grpc.aio.UnaryStreamMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListenRunRequest,
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.StreamEvent,
    ]

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.GetRunRequest,
        yandex.cloud.ai.assistants.v1.runs.run_pb2.Run,
    ]

    GetLastByThread: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.GetLastRunByThreadRequest,
        yandex.cloud.ai.assistants.v1.runs.run_pb2.Run,
    ]

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListRunsRequest,
        yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListRunsResponse,
    ]

class RunServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.ai.assistants.v1.runs.run_service_pb2.CreateRunRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.runs.run_pb2.Run, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.runs.run_pb2.Run]]: ...

    @abc.abstractmethod
    def Listen(
        self,
        request: yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListenRunRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[yandex.cloud.ai.assistants.v1.runs.run_service_pb2.StreamEvent], collections.abc.AsyncIterator[yandex.cloud.ai.assistants.v1.runs.run_service_pb2.StreamEvent]]: ...

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.ai.assistants.v1.runs.run_service_pb2.GetRunRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.runs.run_pb2.Run, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.runs.run_pb2.Run]]: ...

    @abc.abstractmethod
    def GetLastByThread(
        self,
        request: yandex.cloud.ai.assistants.v1.runs.run_service_pb2.GetLastRunByThreadRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.runs.run_pb2.Run, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.runs.run_pb2.Run]]: ...

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListRunsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListRunsResponse, collections.abc.Awaitable[yandex.cloud.ai.assistants.v1.runs.run_service_pb2.ListRunsResponse]]: ...

def add_RunServiceServicer_to_server(servicer: RunServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SnapshotSchedule(google.protobuf.message.Message):
    """A snapshot schedule. For details about the concept, see [documentation](/docs/compute/concepts/snapshot-schedule)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SnapshotSchedule._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: SnapshotSchedule._Status.ValueType  # 0
        CREATING: SnapshotSchedule._Status.ValueType  # 1
        """The snapshot schedule is being created."""
        ACTIVE: SnapshotSchedule._Status.ValueType  # 2
        """The snapshot schedule is on: new disk snapshots will be created, old ones deleted
        (if [SnapshotSchedule.retention_policy] is specified).
        """
        INACTIVE: SnapshotSchedule._Status.ValueType  # 3
        """The schedule is interrupted, snapshots won't be created or deleted."""
        DELETING: SnapshotSchedule._Status.ValueType  # 4
        """The schedule is being deleted."""
        UPDATING: SnapshotSchedule._Status.ValueType  # 5
        """Changes are being made to snapshot schedule settings or a list of attached disks."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: SnapshotSchedule.Status.ValueType  # 0
    CREATING: SnapshotSchedule.Status.ValueType  # 1
    """The snapshot schedule is being created."""
    ACTIVE: SnapshotSchedule.Status.ValueType  # 2
    """The snapshot schedule is on: new disk snapshots will be created, old ones deleted
    (if [SnapshotSchedule.retention_policy] is specified).
    """
    INACTIVE: SnapshotSchedule.Status.ValueType  # 3
    """The schedule is interrupted, snapshots won't be created or deleted."""
    DELETING: SnapshotSchedule.Status.ValueType  # 4
    """The schedule is being deleted."""
    UPDATING: SnapshotSchedule.Status.ValueType  # 5
    """Changes are being made to snapshot schedule settings or a list of attached disks."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SCHEDULE_POLICY_FIELD_NUMBER: builtins.int
    RETENTION_PERIOD_FIELD_NUMBER: builtins.int
    SNAPSHOT_COUNT_FIELD_NUMBER: builtins.int
    SNAPSHOT_SPEC_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the snapshot schedule."""
    folder_id: builtins.str
    """ID of the folder that the snapshot schedule belongs to."""
    name: builtins.str
    """Name of the snapshot schedule.

    The name is unique within the folder.
    """
    description: builtins.str
    """Description of the snapshot schedule."""
    status: global___SnapshotSchedule.Status.ValueType
    """Status of the snapshot schedule."""
    snapshot_count: builtins.int
    """Retention count of the snapshot schedule. Once the number of snapshots created by the schedule exceeds this
    number, the oldest ones are automatically deleted. E.g. if the number is 5, the first snapshot is deleted
    after the sixth one is created, the second is deleted after the seventh one is created, and so on.
    """
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Snapshot schedule labels as `key:value` pairs."""

    @property
    def schedule_policy(self) -> global___SchedulePolicy:
        """Frequency settings of the snapshot schedule."""

    @property
    def retention_period(self) -> google.protobuf.duration_pb2.Duration:
        """Retention period of the snapshot schedule. Once a snapshot created by the schedule reaches this age, it is
        automatically deleted.
        """

    @property
    def snapshot_spec(self) -> global___SnapshotSpec:
        """Attributes of snapshots created by the snapshot schedule."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status: global___SnapshotSchedule.Status.ValueType = ...,
        schedule_policy: global___SchedulePolicy | None = ...,
        retention_period: google.protobuf.duration_pb2.Duration | None = ...,
        snapshot_count: builtins.int = ...,
        snapshot_spec: global___SnapshotSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "retention_period", b"retention_period", "retention_policy", b"retention_policy", "schedule_policy", b"schedule_policy", "snapshot_count", b"snapshot_count", "snapshot_spec", b"snapshot_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "retention_period", b"retention_period", "retention_policy", b"retention_policy", "schedule_policy", b"schedule_policy", "snapshot_count", b"snapshot_count", "snapshot_spec", b"snapshot_spec", "status", b"status"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["retention_policy", b"retention_policy"]) -> typing.Literal["retention_period", "snapshot_count"] | None: ...

global___SnapshotSchedule = SnapshotSchedule

@typing.final
class SchedulePolicy(google.protobuf.message.Message):
    """A resource for frequency settings of a snapshot schedule."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_AT_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    expression: builtins.str
    """Cron expression for the snapshot schedule (UTC+0).

    The expression must consist of five fields (`Minutes Hours Day-of-month Month Day-of-week`) or be one of
    nonstandard predefined expressions (e.g. `@hourly`). For details about the format,
    see [documentation](/docs/compute/concepts/snapshot-schedule#cron)
    """
    @property
    def start_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp for creating the first snapshot."""

    def __init__(
        self,
        *,
        start_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        expression: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["start_at", b"start_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["expression", b"expression", "start_at", b"start_at"]) -> None: ...

global___SchedulePolicy = SchedulePolicy

@typing.final
class SnapshotSpec(google.protobuf.message.Message):
    """A resource for attributes of snapshots created by the snapshot schedule."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    description: builtins.str
    """Description of the created snapshot."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Snapshot labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels"]) -> None: ...

global___SnapshotSpec = SnapshotSpec



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/assistants/v1/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/ai/assistants/v1/common.proto\x12\x1dyandex.cloud.ai.assistants.v1\x1a\x1egoogle/protobuf/wrappers.proto\"Q\n\x17PromptTruncationOptions\x12\x36\n\x11max_prompt_tokens\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"w\n\x11\x43ompletionOptions\x12/\n\nmax_tokens\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0btemperature\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"a\n\x0fSearchIndexTool\x12\x18\n\x10search_index_ids\x18\x01 \x03(\t\x12\x34\n\x0fmax_num_results\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"Z\n\x04Tool\x12\x46\n\x0csearch_index\x18\x01 \x01(\x0b\x32..yandex.cloud.ai.assistants.v1.SearchIndexToolH\x00\x42\n\n\x08ToolTypeBq\n!yandex.cloud.api.ai.assistants.v1ZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1;assistantsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!yandex.cloud.api.ai.assistants.v1ZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1;assistants'
  _globals['_PROMPTTRUNCATIONOPTIONS']._serialized_start=109
  _globals['_PROMPTTRUNCATIONOPTIONS']._serialized_end=190
  _globals['_COMPLETIONOPTIONS']._serialized_start=192
  _globals['_COMPLETIONOPTIONS']._serialized_end=311
  _globals['_SEARCHINDEXTOOL']._serialized_start=313
  _globals['_SEARCHINDEXTOOL']._serialized_end=410
  _globals['_TOOL']._serialized_start=412
  _globals['_TOOL']._serialized_end=502
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/assistants/v1/threads/message.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/ai/assistants/v1/threads/message.proto\x12%yandex.cloud.ai.assistants.v1.threads\x1a\x1fgoogle/protobuf/timestamp.proto\"\xee\x02\n\x07Message\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tthread_id\x18\x02 \x01(\t\x12\x12\n\ncreated_by\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x06\x61uthor\x18\x05 \x01(\x0b\x32-.yandex.cloud.ai.assistants.v1.threads.Author\x12J\n\x06labels\x18\x06 \x03(\x0b\x32:.yandex.cloud.ai.assistants.v1.threads.Message.LabelsEntry\x12\x46\n\x07\x63ontent\x18\x07 \x01(\x0b\x32\x35.yandex.cloud.ai.assistants.v1.threads.MessageContent\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n\x0eMessageContent\x12\x43\n\x07\x63ontent\x18\x01 \x03(\x0b\x32\x32.yandex.cloud.ai.assistants.v1.threads.ContentPart\"\x93\x02\n\x0bMessageData\x12=\n\x06\x61uthor\x18\x01 \x01(\x0b\x32-.yandex.cloud.ai.assistants.v1.threads.Author\x12N\n\x06labels\x18\x02 \x03(\x0b\x32>.yandex.cloud.ai.assistants.v1.threads.MessageData.LabelsEntry\x12\x46\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.ai.assistants.v1.threads.MessageContent\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x17\n\x04Text\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\"V\n\x0b\x43ontentPart\x12;\n\x04text\x18\x01 \x01(\x0b\x32+.yandex.cloud.ai.assistants.v1.threads.TextH\x00\x42\n\n\x08PartType\"\"\n\x06\x41uthor\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\tB~\n)yandex.cloud.api.ai.assistants.v1.threadsZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/threads;threadsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.threads.message_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.ai.assistants.v1.threadsZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/threads;threads'
  _MESSAGE_LABELSENTRY._options = None
  _MESSAGE_LABELSENTRY._serialized_options = b'8\001'
  _MESSAGEDATA_LABELSENTRY._options = None
  _MESSAGEDATA_LABELSENTRY._serialized_options = b'8\001'
  _globals['_MESSAGE']._serialized_start=128
  _globals['_MESSAGE']._serialized_end=494
  _globals['_MESSAGE_LABELSENTRY']._serialized_start=449
  _globals['_MESSAGE_LABELSENTRY']._serialized_end=494
  _globals['_MESSAGECONTENT']._serialized_start=496
  _globals['_MESSAGECONTENT']._serialized_end=581
  _globals['_MESSAGEDATA']._serialized_start=584
  _globals['_MESSAGEDATA']._serialized_end=859
  _globals['_MESSAGEDATA_LABELSENTRY']._serialized_start=449
  _globals['_MESSAGEDATA_LABELSENTRY']._serialized_end=494
  _globals['_TEXT']._serialized_start=861
  _globals['_TEXT']._serialized_end=884
  _globals['_CONTENTPART']._serialized_start=886
  _globals['_CONTENTPART']._serialized_end=972
  _globals['_AUTHOR']._serialized_start=974
  _globals['_AUTHOR']._serialized_end=1008
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/common/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#yandex/cloud/ai/common/common.proto\x12\x16yandex.cloud.ai.common\"\xd4\x01\n\x10\x45xpirationConfig\x12T\n\x11\x65xpiration_policy\x18\x01 \x01(\x0e\x32\x39.yandex.cloud.ai.common.ExpirationConfig.ExpirationPolicy\x12\x10\n\x08ttl_days\x18\x02 \x01(\x03\"X\n\x10\x45xpirationPolicy\x12!\n\x1d\x45XPIRATION_POLICY_UNSPECIFIED\x10\x00\x12\n\n\x06STATIC\x10\x01\x12\x15\n\x11SINCE_LAST_ACTIVE\x10\x02\"&\n\x05\x45rror\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\x12\x0f\n\x07message\x18\x02 \x01(\tB_\n\x1ayandex.cloud.api.ai.commonZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/common;commonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.common.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032yandex.cloud.api.ai.commonZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/common;common'
  _globals['_EXPIRATIONCONFIG']._serialized_start=64
  _globals['_EXPIRATIONCONFIG']._serialized_end=276
  _globals['_EXPIRATIONCONFIG_EXPIRATIONPOLICY']._serialized_start=188
  _globals['_EXPIRATIONCONFIG_EXPIRATIONPOLICY']._serialized_end=276
  _globals['_ERROR']._serialized_start=278
  _globals['_ERROR']._serialized_end=316
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import google.rpc.code_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _HttpCodeInterval:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HttpCodeIntervalEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HttpCodeInterval.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    HTTP_CODE_INTERVAL_UNSPECIFIED: _HttpCodeInterval.ValueType  # 0
    HTTP_1XX: _HttpCodeInterval.ValueType  # 1
    HTTP_2XX: _HttpCodeInterval.ValueType  # 2
    HTTP_3XX: _HttpCodeInterval.ValueType  # 3
    HTTP_4XX: _HttpCodeInterval.ValueType  # 4
    HTTP_5XX: _HttpCodeInterval.ValueType  # 5
    HTTP_ALL: _HttpCodeInterval.ValueType  # 6

class HttpCodeInterval(_HttpCodeInterval, metaclass=_HttpCodeIntervalEnumTypeWrapper): ...

HTTP_CODE_INTERVAL_UNSPECIFIED: HttpCodeInterval.ValueType  # 0
HTTP_1XX: HttpCodeInterval.ValueType  # 1
HTTP_2XX: HttpCodeInterval.ValueType  # 2
HTTP_3XX: HttpCodeInterval.ValueType  # 3
HTTP_4XX: HttpCodeInterval.ValueType  # 4
HTTP_5XX: HttpCodeInterval.ValueType  # 5
HTTP_ALL: HttpCodeInterval.ValueType  # 6
global___HttpCodeInterval = HttpCodeInterval

@typing.final
class LogDiscardRule(google.protobuf.message.Message):
    """LogDiscardRule discards a fraction of logs with certain codes.
    If neither codes or intervals are provided, rule applies to all logs.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_CODES_FIELD_NUMBER: builtins.int
    HTTP_CODE_INTERVALS_FIELD_NUMBER: builtins.int
    GRPC_CODES_FIELD_NUMBER: builtins.int
    DISCARD_PERCENT_FIELD_NUMBER: builtins.int
    @property
    def http_codes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """HTTP codes that should be discarded."""

    @property
    def http_code_intervals(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___HttpCodeInterval.ValueType]:
        """Groups of HTTP codes like 4xx that should be discarded."""

    @property
    def grpc_codes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[google.rpc.code_pb2.Code.ValueType]:
        """GRPC codes that should be discarded"""

    @property
    def discard_percent(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Percent of logs to be discarded: 0 - keep all, 100 or unset - discard all"""

    def __init__(
        self,
        *,
        http_codes: collections.abc.Iterable[builtins.int] | None = ...,
        http_code_intervals: collections.abc.Iterable[global___HttpCodeInterval.ValueType] | None = ...,
        grpc_codes: collections.abc.Iterable[google.rpc.code_pb2.Code.ValueType] | None = ...,
        discard_percent: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["discard_percent", b"discard_percent"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["discard_percent", b"discard_percent", "grpc_codes", b"grpc_codes", "http_code_intervals", b"http_code_intervals", "http_codes", b"http_codes"]) -> None: ...

global___LogDiscardRule = LogDiscardRule

@typing.final
class LogOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    DISCARD_RULES_FIELD_NUMBER: builtins.int
    DISABLE_FIELD_NUMBER: builtins.int
    log_group_id: builtins.str
    """Cloud Logging log group ID to store access logs.
    If not set then logs will be stored in default log group for the folder
    where load balancer located.
    """
    disable: builtins.bool
    """Do not send logs to Cloud Logging log group."""
    @property
    def discard_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LogDiscardRule]:
        """ordered list of rules, first matching rule applies"""

    def __init__(
        self,
        *,
        log_group_id: builtins.str = ...,
        discard_rules: collections.abc.Iterable[global___LogDiscardRule] | None = ...,
        disable: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disable", b"disable", "discard_rules", b"discard_rules", "log_group_id", b"log_group_id"]) -> None: ...

global___LogOptions = LogOptions



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/resourcemanager/v1/cloud.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/resourcemanager/v1/cloud.proto\x12\x1fyandex.cloud.resourcemanager.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf8\x01\n\x05\x43loud\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x17\n\x0forganization_id\x18\x06 \x01(\t\x12\x42\n\x06labels\x18\x07 \x03(\x0b\x32\x32.yandex.cloud.resourcemanager.v1.Cloud.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x05\x10\x06\x42z\n#yandex.cloud.api.resourcemanager.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/resourcemanager/v1;resourcemanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.resourcemanager.v1.cloud_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.resourcemanager.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/resourcemanager/v1;resourcemanager'
  _CLOUD_LABELSENTRY._options = None
  _CLOUD_LABELSENTRY._serialized_options = b'8\001'
  _globals['_CLOUD']._serialized_start=114
  _globals['_CLOUD']._serialized_end=362
  _globals['_CLOUD_LABELSENTRY']._serialized_start=311
  _globals['_CLOUD_LABELSENTRY']._serialized_end=356
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/opensearch/v1/auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/mdb/opensearch/v1/auth.proto\x12\x1eyandex.cloud.mdb.opensearch.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"J\n\x0c\x41uthSettings\x12:\n\x04saml\x18\x01 \x01(\x0b\x32,.yandex.cloud.mdb.opensearch.v1.SAMLSettings\"\xb0\x02\n\x0cSAMLSettings\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12 \n\ridp_entity_id\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12&\n\x11idp_metadata_file\x18\x03 \x01(\x0c\x42\x0b\x8a\xc8\x31\x07<=10000\x12\x1f\n\x0csp_entity_id\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12!\n\x0e\x64\x61shboards_url\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12\x1c\n\troles_key\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12\x1e\n\x0bsubject_key\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12\x43\n\x1ejwt_default_expiration_timeout\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueBs\n\"yandex.cloud.api.mdb.opensearch.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/opensearch/v1;opensearchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.opensearch.v1.auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"yandex.cloud.api.mdb.opensearch.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/opensearch/v1;opensearch'
  _SAMLSETTINGS.fields_by_name['idp_entity_id']._options = None
  _SAMLSETTINGS.fields_by_name['idp_entity_id']._serialized_options = b'\212\3101\005<=250'
  _SAMLSETTINGS.fields_by_name['idp_metadata_file']._options = None
  _SAMLSETTINGS.fields_by_name['idp_metadata_file']._serialized_options = b'\212\3101\007<=10000'
  _SAMLSETTINGS.fields_by_name['sp_entity_id']._options = None
  _SAMLSETTINGS.fields_by_name['sp_entity_id']._serialized_options = b'\212\3101\005<=250'
  _SAMLSETTINGS.fields_by_name['dashboards_url']._options = None
  _SAMLSETTINGS.fields_by_name['dashboards_url']._serialized_options = b'\212\3101\005<=250'
  _SAMLSETTINGS.fields_by_name['roles_key']._options = None
  _SAMLSETTINGS.fields_by_name['roles_key']._serialized_options = b'\212\3101\005<=250'
  _SAMLSETTINGS.fields_by_name['subject_key']._options = None
  _SAMLSETTINGS.fields_by_name['subject_key']._serialized_options = b'\212\3101\005<=250'
  _globals['_AUTHSETTINGS']._serialized_start=140
  _globals['_AUTHSETTINGS']._serialized_end=214
  _globals['_SAMLSETTINGS']._serialized_start=217
  _globals['_SAMLSETTINGS']._serialized_end=521
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import google.type.timeofday_pb2
import sys
import typing
import yandex.cloud.mdb.postgresql.v1.config.host10_1c_pb2
import yandex.cloud.mdb.postgresql.v1.config.host10_pb2
import yandex.cloud.mdb.postgresql.v1.config.host11_1c_pb2
import yandex.cloud.mdb.postgresql.v1.config.host11_pb2
import yandex.cloud.mdb.postgresql.v1.config.host12_1c_pb2
import yandex.cloud.mdb.postgresql.v1.config.host12_pb2
import yandex.cloud.mdb.postgresql.v1.config.host13_1c_pb2
import yandex.cloud.mdb.postgresql.v1.config.host13_pb2
import yandex.cloud.mdb.postgresql.v1.config.host14_1c_pb2
import yandex.cloud.mdb.postgresql.v1.config.host14_pb2
import yandex.cloud.mdb.postgresql.v1.config.host15_1c_pb2
import yandex.cloud.mdb.postgresql.v1.config.host15_pb2
import yandex.cloud.mdb.postgresql.v1.config.host16_1c_pb2
import yandex.cloud.mdb.postgresql.v1.config.host16_pb2
import yandex.cloud.mdb.postgresql.v1.config.host9_6_pb2
import yandex.cloud.mdb.postgresql.v1.config.postgresql10_1c_pb2
import yandex.cloud.mdb.postgresql.v1.config.postgresql10_pb2
import yandex.cloud.mdb.postgresql.v1.config.postgresql11_1c_pb2
import yandex.cloud.mdb.postgresql.v1.config.postgresql11_pb2
import yandex.cloud.mdb.postgresql.v1.config.postgresql12_1c_pb2
import yandex.cloud.mdb.postgresql.v1.config.postgresql12_pb2
import yandex.cloud.mdb.postgresql.v1.config.postgresql13_1c_pb2
import yandex.cloud.mdb.postgresql.v1.config.postgresql13_pb2
import yandex.cloud.mdb.postgresql.v1.config.postgresql14_1c_pb2
import yandex.cloud.mdb.postgresql.v1.config.postgresql14_pb2
import yandex.cloud.mdb.postgresql.v1.config.postgresql15_1c_pb2
import yandex.cloud.mdb.postgresql.v1.config.postgresql15_pb2
import yandex.cloud.mdb.postgresql.v1.config.postgresql16_1c_pb2
import yandex.cloud.mdb.postgresql.v1.config.postgresql16_pb2
import yandex.cloud.mdb.postgresql.v1.config.postgresql9_6_pb2
import yandex.cloud.mdb.postgresql.v1.maintenance_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Cluster(google.protobuf.message.Message):
    """A PostgreSQL Cluster resource. For more information, see
    the [Concepts](/docs/managed-postgresql/concepts) section of the documentation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Environment:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EnvironmentEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Environment.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ENVIRONMENT_UNSPECIFIED: Cluster._Environment.ValueType  # 0
        PRODUCTION: Cluster._Environment.ValueType  # 1
        """Stable environment with a conservative update policy:
        only hotfixes are applied during regular maintenance.
        """
        PRESTABLE: Cluster._Environment.ValueType  # 2
        """Environment with more aggressive update policy: new versions
        are rolled out irrespective of backward compatibility.
        """

    class Environment(_Environment, metaclass=_EnvironmentEnumTypeWrapper): ...
    ENVIRONMENT_UNSPECIFIED: Cluster.Environment.ValueType  # 0
    PRODUCTION: Cluster.Environment.ValueType  # 1
    """Stable environment with a conservative update policy:
    only hotfixes are applied during regular maintenance.
    """
    PRESTABLE: Cluster.Environment.ValueType  # 2
    """Environment with more aggressive update policy: new versions
    are rolled out irrespective of backward compatibility.
    """

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Cluster._Health.ValueType  # 0
        """State of the cluster is unknown ([Host.health] for every host in the cluster is UNKNOWN)."""
        ALIVE: Cluster._Health.ValueType  # 1
        """Cluster is alive and well ([Host.health] for every host in the cluster is ALIVE)."""
        DEAD: Cluster._Health.ValueType  # 2
        """Cluster is inoperable ([Host.health] for every host in the cluster is DEAD)."""
        DEGRADED: Cluster._Health.ValueType  # 3
        """Cluster is working below capacity ([Host.health] for at least one host in the cluster is not ALIVE)."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Cluster.Health.ValueType  # 0
    """State of the cluster is unknown ([Host.health] for every host in the cluster is UNKNOWN)."""
    ALIVE: Cluster.Health.ValueType  # 1
    """Cluster is alive and well ([Host.health] for every host in the cluster is ALIVE)."""
    DEAD: Cluster.Health.ValueType  # 2
    """Cluster is inoperable ([Host.health] for every host in the cluster is DEAD)."""
    DEGRADED: Cluster.Health.ValueType  # 3
    """Cluster is working below capacity ([Host.health] for at least one host in the cluster is not ALIVE)."""

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Cluster._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNKNOWN: Cluster._Status.ValueType  # 0
        """Cluster state is unknown."""
        CREATING: Cluster._Status.ValueType  # 1
        """Cluster is being created."""
        RUNNING: Cluster._Status.ValueType  # 2
        """Cluster is running normally."""
        ERROR: Cluster._Status.ValueType  # 3
        """Cluster encountered a problem and cannot operate."""
        UPDATING: Cluster._Status.ValueType  # 4
        """Cluster is being updated."""
        STOPPING: Cluster._Status.ValueType  # 5
        """Cluster is stopping."""
        STOPPED: Cluster._Status.ValueType  # 6
        """Cluster stopped."""
        STARTING: Cluster._Status.ValueType  # 7
        """Cluster is starting."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNKNOWN: Cluster.Status.ValueType  # 0
    """Cluster state is unknown."""
    CREATING: Cluster.Status.ValueType  # 1
    """Cluster is being created."""
    RUNNING: Cluster.Status.ValueType  # 2
    """Cluster is running normally."""
    ERROR: Cluster.Status.ValueType  # 3
    """Cluster encountered a problem and cannot operate."""
    UPDATING: Cluster.Status.ValueType  # 4
    """Cluster is being updated."""
    STOPPING: Cluster.Status.ValueType  # 5
    """Cluster is stopping."""
    STOPPED: Cluster.Status.ValueType  # 6
    """Cluster stopped."""
    STARTING: Cluster.Status.ValueType  # 7
    """Cluster is starting."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    MONITORING_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    PLANNED_OPERATION_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    HOST_GROUP_IDS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the PostgreSQL cluster.
    This ID is assigned by MDB at creation time.
    """
    folder_id: builtins.str
    """ID of the folder that the PostgreSQL cluster belongs to."""
    name: builtins.str
    """Name of the PostgreSQL cluster.
    The name is unique within the folder. 1-63 characters long.
    """
    description: builtins.str
    """Description of the PostgreSQL cluster. 0-256 characters long."""
    environment: global___Cluster.Environment.ValueType
    """Deployment environment of the PostgreSQL cluster."""
    network_id: builtins.str
    """ID of the network that the cluster belongs to."""
    health: global___Cluster.Health.ValueType
    """Aggregated cluster health."""
    status: global___Cluster.Status.ValueType
    """Current state of the cluster."""
    deletion_protection: builtins.bool
    """Deletion Protection inhibits deletion of the cluster"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the PostgreSQL cluster as `` key:value `` pairs.
        Maximum 64 per resource.
        """

    @property
    def monitoring(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Monitoring]:
        """Description of monitoring systems relevant to the PostgreSQL cluster."""

    @property
    def config(self) -> global___ClusterConfig:
        """Configuration of the PostgreSQL cluster."""

    @property
    def maintenance_window(self) -> yandex.cloud.mdb.postgresql.v1.maintenance_pb2.MaintenanceWindow:
        """Maintenance window for the cluster."""

    @property
    def planned_operation(self) -> yandex.cloud.mdb.postgresql.v1.maintenance_pb2.MaintenanceOperation:
        """Planned maintenance operation to be started for the cluster within the nearest [maintenance_window]."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups"""

    @property
    def host_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Host groups hosting VMs of the cluster."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        environment: global___Cluster.Environment.ValueType = ...,
        monitoring: collections.abc.Iterable[global___Monitoring] | None = ...,
        config: global___ClusterConfig | None = ...,
        network_id: builtins.str = ...,
        health: global___Cluster.Health.ValueType = ...,
        status: global___Cluster.Status.ValueType = ...,
        maintenance_window: yandex.cloud.mdb.postgresql.v1.maintenance_pb2.MaintenanceWindow | None = ...,
        planned_operation: yandex.cloud.mdb.postgresql.v1.maintenance_pb2.MaintenanceOperation | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        host_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at", "maintenance_window", b"maintenance_window", "planned_operation", b"planned_operation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "environment", b"environment", "folder_id", b"folder_id", "health", b"health", "host_group_ids", b"host_group_ids", "id", b"id", "labels", b"labels", "maintenance_window", b"maintenance_window", "monitoring", b"monitoring", "name", b"name", "network_id", b"network_id", "planned_operation", b"planned_operation", "security_group_ids", b"security_group_ids", "status", b"status"]) -> None: ...

global___Cluster = Cluster

@typing.final
class Monitoring(google.protobuf.message.Message):
    """Monitoring system."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the monitoring system."""
    description: builtins.str
    """Description of the monitoring system."""
    link: builtins.str
    """Link to the monitoring system charts for the PostgreSQL cluster."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "link", b"link", "name", b"name"]) -> None: ...

global___Monitoring = Monitoring

@typing.final
class ClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_9_6_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_10_1C_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_10_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_11_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_11_1C_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_12_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_12_1C_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_13_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_13_1C_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_14_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_14_1C_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_15_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_15_1C_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_16_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_16_1C_FIELD_NUMBER: builtins.int
    POOLER_CONFIG_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    AUTOFAILOVER_FIELD_NUMBER: builtins.int
    BACKUP_WINDOW_START_FIELD_NUMBER: builtins.int
    BACKUP_RETAIN_PERIOD_DAYS_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    PERFORMANCE_DIAGNOSTICS_FIELD_NUMBER: builtins.int
    DISK_SIZE_AUTOSCALING_FIELD_NUMBER: builtins.int
    version: builtins.str
    """Version of PostgreSQL server software."""
    @property
    def postgresql_config_9_6(self) -> yandex.cloud.mdb.postgresql.v1.config.postgresql9_6_pb2.PostgresqlConfigSet9_6:
        """Configuration of a PostgreSQL 9.6 server."""

    @property
    def postgresql_config_10_1c(self) -> yandex.cloud.mdb.postgresql.v1.config.postgresql10_1c_pb2.PostgresqlConfigSet10_1C:
        """Configuration of a PostgreSQL 10 1C server."""

    @property
    def postgresql_config_10(self) -> yandex.cloud.mdb.postgresql.v1.config.postgresql10_pb2.PostgresqlConfigSet10:
        """Configuration of a PostgreSQL 10 server."""

    @property
    def postgresql_config_11(self) -> yandex.cloud.mdb.postgresql.v1.config.postgresql11_pb2.PostgresqlConfigSet11:
        """Configuration of a PostgreSQL 11 server."""

    @property
    def postgresql_config_11_1c(self) -> yandex.cloud.mdb.postgresql.v1.config.postgresql11_1c_pb2.PostgresqlConfigSet11_1C:
        """Configuration of a PostgreSQL 11 1C server."""

    @property
    def postgresql_config_12(self) -> yandex.cloud.mdb.postgresql.v1.config.postgresql12_pb2.PostgresqlConfigSet12:
        """Configuration of a PostgreSQL 12 server."""

    @property
    def postgresql_config_12_1c(self) -> yandex.cloud.mdb.postgresql.v1.config.postgresql12_1c_pb2.PostgresqlConfigSet12_1C:
        """Configuration of a PostgreSQL 12 1C server."""

    @property
    def postgresql_config_13(self) -> yandex.cloud.mdb.postgresql.v1.config.postgresql13_pb2.PostgresqlConfigSet13:
        """Configuration of a PostgreSQL 13 server."""

    @property
    def postgresql_config_13_1c(self) -> yandex.cloud.mdb.postgresql.v1.config.postgresql13_1c_pb2.PostgresqlConfigSet13_1C:
        """Configuration of a PostgreSQL 13 1C server."""

    @property
    def postgresql_config_14(self) -> yandex.cloud.mdb.postgresql.v1.config.postgresql14_pb2.PostgresqlConfigSet14:
        """Configuration of a PostgreSQL 14 server."""

    @property
    def postgresql_config_14_1c(self) -> yandex.cloud.mdb.postgresql.v1.config.postgresql14_1c_pb2.PostgresqlConfigSet14_1C:
        """Configuration of a PostgreSQL 14 1C server."""

    @property
    def postgresql_config_15(self) -> yandex.cloud.mdb.postgresql.v1.config.postgresql15_pb2.PostgresqlConfigSet15:
        """Configuration of a PostgreSQL 15 server."""

    @property
    def postgresql_config_15_1c(self) -> yandex.cloud.mdb.postgresql.v1.config.postgresql15_1c_pb2.PostgresqlConfigSet15_1C:
        """Configuration of a PostgreSQL 15 1C server."""

    @property
    def postgresql_config_16(self) -> yandex.cloud.mdb.postgresql.v1.config.postgresql16_pb2.PostgresqlConfigSet16:
        """Configuration of a PostgreSQL 16 server."""

    @property
    def postgresql_config_16_1c(self) -> yandex.cloud.mdb.postgresql.v1.config.postgresql16_1c_pb2.PostgresqlConfigSet16_1C:
        """Configuration of a PostgreSQL 16 1C server."""

    @property
    def pooler_config(self) -> global___ConnectionPoolerConfig:
        """Configuration of the connection pooler."""

    @property
    def resources(self) -> global___Resources:
        """Resources allocated to PostgreSQL hosts."""

    @property
    def autofailover(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Configuration setting which enables/disables autofailover in cluster."""

    @property
    def backup_window_start(self) -> google.type.timeofday_pb2.TimeOfDay:
        """Time to start the daily backup, in the UTC timezone."""

    @property
    def backup_retain_period_days(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Retention policy of automated backups."""

    @property
    def access(self) -> global___Access:
        """Access policy to DB"""

    @property
    def performance_diagnostics(self) -> global___PerformanceDiagnostics:
        """Configuration of the performance diagnostics service."""

    @property
    def disk_size_autoscaling(self) -> global___DiskSizeAutoscaling:
        """Disk size autoscaling"""

    def __init__(
        self,
        *,
        version: builtins.str = ...,
        postgresql_config_9_6: yandex.cloud.mdb.postgresql.v1.config.postgresql9_6_pb2.PostgresqlConfigSet9_6 | None = ...,
        postgresql_config_10_1c: yandex.cloud.mdb.postgresql.v1.config.postgresql10_1c_pb2.PostgresqlConfigSet10_1C | None = ...,
        postgresql_config_10: yandex.cloud.mdb.postgresql.v1.config.postgresql10_pb2.PostgresqlConfigSet10 | None = ...,
        postgresql_config_11: yandex.cloud.mdb.postgresql.v1.config.postgresql11_pb2.PostgresqlConfigSet11 | None = ...,
        postgresql_config_11_1c: yandex.cloud.mdb.postgresql.v1.config.postgresql11_1c_pb2.PostgresqlConfigSet11_1C | None = ...,
        postgresql_config_12: yandex.cloud.mdb.postgresql.v1.config.postgresql12_pb2.PostgresqlConfigSet12 | None = ...,
        postgresql_config_12_1c: yandex.cloud.mdb.postgresql.v1.config.postgresql12_1c_pb2.PostgresqlConfigSet12_1C | None = ...,
        postgresql_config_13: yandex.cloud.mdb.postgresql.v1.config.postgresql13_pb2.PostgresqlConfigSet13 | None = ...,
        postgresql_config_13_1c: yandex.cloud.mdb.postgresql.v1.config.postgresql13_1c_pb2.PostgresqlConfigSet13_1C | None = ...,
        postgresql_config_14: yandex.cloud.mdb.postgresql.v1.config.postgresql14_pb2.PostgresqlConfigSet14 | None = ...,
        postgresql_config_14_1c: yandex.cloud.mdb.postgresql.v1.config.postgresql14_1c_pb2.PostgresqlConfigSet14_1C | None = ...,
        postgresql_config_15: yandex.cloud.mdb.postgresql.v1.config.postgresql15_pb2.PostgresqlConfigSet15 | None = ...,
        postgresql_config_15_1c: yandex.cloud.mdb.postgresql.v1.config.postgresql15_1c_pb2.PostgresqlConfigSet15_1C | None = ...,
        postgresql_config_16: yandex.cloud.mdb.postgresql.v1.config.postgresql16_pb2.PostgresqlConfigSet16 | None = ...,
        postgresql_config_16_1c: yandex.cloud.mdb.postgresql.v1.config.postgresql16_1c_pb2.PostgresqlConfigSet16_1C | None = ...,
        pooler_config: global___ConnectionPoolerConfig | None = ...,
        resources: global___Resources | None = ...,
        autofailover: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        backup_window_start: google.type.timeofday_pb2.TimeOfDay | None = ...,
        backup_retain_period_days: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        access: global___Access | None = ...,
        performance_diagnostics: global___PerformanceDiagnostics | None = ...,
        disk_size_autoscaling: global___DiskSizeAutoscaling | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access", b"access", "autofailover", b"autofailover", "backup_retain_period_days", b"backup_retain_period_days", "backup_window_start", b"backup_window_start", "disk_size_autoscaling", b"disk_size_autoscaling", "performance_diagnostics", b"performance_diagnostics", "pooler_config", b"pooler_config", "postgresql_config", b"postgresql_config", "postgresql_config_10", b"postgresql_config_10", "postgresql_config_10_1c", b"postgresql_config_10_1c", "postgresql_config_11", b"postgresql_config_11", "postgresql_config_11_1c", b"postgresql_config_11_1c", "postgresql_config_12", b"postgresql_config_12", "postgresql_config_12_1c", b"postgresql_config_12_1c", "postgresql_config_13", b"postgresql_config_13", "postgresql_config_13_1c", b"postgresql_config_13_1c", "postgresql_config_14", b"postgresql_config_14", "postgresql_config_14_1c", b"postgresql_config_14_1c", "postgresql_config_15", b"postgresql_config_15", "postgresql_config_15_1c", b"postgresql_config_15_1c", "postgresql_config_16", b"postgresql_config_16", "postgresql_config_16_1c", b"postgresql_config_16_1c", "postgresql_config_9_6", b"postgresql_config_9_6", "resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access", b"access", "autofailover", b"autofailover", "backup_retain_period_days", b"backup_retain_period_days", "backup_window_start", b"backup_window_start", "disk_size_autoscaling", b"disk_size_autoscaling", "performance_diagnostics", b"performance_diagnostics", "pooler_config", b"pooler_config", "postgresql_config", b"postgresql_config", "postgresql_config_10", b"postgresql_config_10", "postgresql_config_10_1c", b"postgresql_config_10_1c", "postgresql_config_11", b"postgresql_config_11", "postgresql_config_11_1c", b"postgresql_config_11_1c", "postgresql_config_12", b"postgresql_config_12", "postgresql_config_12_1c", b"postgresql_config_12_1c", "postgresql_config_13", b"postgresql_config_13", "postgresql_config_13_1c", b"postgresql_config_13_1c", "postgresql_config_14", b"postgresql_config_14", "postgresql_config_14_1c", b"postgresql_config_14_1c", "postgresql_config_15", b"postgresql_config_15", "postgresql_config_15_1c", b"postgresql_config_15_1c", "postgresql_config_16", b"postgresql_config_16", "postgresql_config_16_1c", b"postgresql_config_16_1c", "postgresql_config_9_6", b"postgresql_config_9_6", "resources", b"resources", "version", b"version"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["postgresql_config", b"postgresql_config"]) -> typing.Literal["postgresql_config_9_6", "postgresql_config_10_1c", "postgresql_config_10", "postgresql_config_11", "postgresql_config_11_1c", "postgresql_config_12", "postgresql_config_12_1c", "postgresql_config_13", "postgresql_config_13_1c", "postgresql_config_14", "postgresql_config_14_1c", "postgresql_config_15", "postgresql_config_15_1c", "postgresql_config_16", "postgresql_config_16_1c"] | None: ...

global___ClusterConfig = ClusterConfig

@typing.final
class ConnectionPoolerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _PoolingMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PoolingModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ConnectionPoolerConfig._PoolingMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        POOLING_MODE_UNSPECIFIED: ConnectionPoolerConfig._PoolingMode.ValueType  # 0
        SESSION: ConnectionPoolerConfig._PoolingMode.ValueType  # 1
        """Session pooling mode."""
        TRANSACTION: ConnectionPoolerConfig._PoolingMode.ValueType  # 2
        """Transaction pooling mode."""
        STATEMENT: ConnectionPoolerConfig._PoolingMode.ValueType  # 3
        """Statement pooling mode."""

    class PoolingMode(_PoolingMode, metaclass=_PoolingModeEnumTypeWrapper): ...
    POOLING_MODE_UNSPECIFIED: ConnectionPoolerConfig.PoolingMode.ValueType  # 0
    SESSION: ConnectionPoolerConfig.PoolingMode.ValueType  # 1
    """Session pooling mode."""
    TRANSACTION: ConnectionPoolerConfig.PoolingMode.ValueType  # 2
    """Transaction pooling mode."""
    STATEMENT: ConnectionPoolerConfig.PoolingMode.ValueType  # 3
    """Statement pooling mode."""

    POOLING_MODE_FIELD_NUMBER: builtins.int
    POOL_DISCARD_FIELD_NUMBER: builtins.int
    pooling_mode: global___ConnectionPoolerConfig.PoolingMode.ValueType
    """Mode that the connection pooler is working in.
    See descriptions of all modes in the [documentation for PgBouncer](https://pgbouncer.github.io/usage).
    """
    @property
    def pool_discard(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Setting `server_reset_query_always` parameter in PgBouncer."""

    def __init__(
        self,
        *,
        pooling_mode: global___ConnectionPoolerConfig.PoolingMode.ValueType = ...,
        pool_discard: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pool_discard", b"pool_discard"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["pool_discard", b"pool_discard", "pooling_mode", b"pooling_mode"]) -> None: ...

global___ConnectionPoolerConfig = ConnectionPoolerConfig

@typing.final
class Host(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Role:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Role.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ROLE_UNKNOWN: Host._Role.ValueType  # 0
        """Role of the host in the cluster is unknown. Default value."""
        MASTER: Host._Role.ValueType  # 1
        """Host is the master PostgreSQL server in the cluster."""
        REPLICA: Host._Role.ValueType  # 2
        """Host is a replica (standby) PostgreSQL server in the cluster."""

    class Role(_Role, metaclass=_RoleEnumTypeWrapper): ...
    ROLE_UNKNOWN: Host.Role.ValueType  # 0
    """Role of the host in the cluster is unknown. Default value."""
    MASTER: Host.Role.ValueType  # 1
    """Host is the master PostgreSQL server in the cluster."""
    REPLICA: Host.Role.ValueType  # 2
    """Host is a replica (standby) PostgreSQL server in the cluster."""

    class _ReplicaType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ReplicaTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._ReplicaType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        REPLICA_TYPE_UNKNOWN: Host._ReplicaType.ValueType  # 0
        """Replica type is unknown (we have no data) or it's master"""
        ASYNC: Host._ReplicaType.ValueType  # 1
        SYNC: Host._ReplicaType.ValueType  # 2
        QUORUM: Host._ReplicaType.ValueType  # 3

    class ReplicaType(_ReplicaType, metaclass=_ReplicaTypeEnumTypeWrapper): ...
    REPLICA_TYPE_UNKNOWN: Host.ReplicaType.ValueType  # 0
    """Replica type is unknown (we have no data) or it's master"""
    ASYNC: Host.ReplicaType.ValueType  # 1
    SYNC: Host.ReplicaType.ValueType  # 2
    QUORUM: Host.ReplicaType.ValueType  # 3

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Host._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Host._Health.ValueType  # 0
        """Health of the host is unknown. Default value."""
        ALIVE: Host._Health.ValueType  # 1
        """The host is performing all its functions normally."""
        DEAD: Host._Health.ValueType  # 2
        """The host is inoperable, and cannot perform any of its essential functions."""
        DEGRADED: Host._Health.ValueType  # 3
        """The host is degraded, and can perform only some of its essential functions."""
        READONLY: Host._Health.ValueType  # 4
        """The host is alive, but in read-only mode."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Host.Health.ValueType  # 0
    """Health of the host is unknown. Default value."""
    ALIVE: Host.Health.ValueType  # 1
    """The host is performing all its functions normally."""
    DEAD: Host.Health.ValueType  # 2
    """The host is inoperable, and cannot perform any of its essential functions."""
    DEGRADED: Host.Health.ValueType  # 3
    """The host is degraded, and can perform only some of its essential functions."""
    READONLY: Host.Health.ValueType  # 4
    """The host is alive, but in read-only mode."""

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    SERVICES_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    REPLICATION_SOURCE_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    ASSIGN_PUBLIC_IP_FIELD_NUMBER: builtins.int
    REPLICA_TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the PostgreSQL host. The host name is assigned by MDB at creation time, and cannot be changed.
    1-63 characters long.

    The name is unique across all MDB hosts that exist on the platform, as it defines the FQDN of the host.
    """
    cluster_id: builtins.str
    """ID of the PostgreSQL host. The ID is assigned by MDB at creation time."""
    zone_id: builtins.str
    """ID of the availability zone where the PostgreSQL host resides."""
    role: global___Host.Role.ValueType
    """Role of the host in the cluster. If the field has default value, it is not returned in the response."""
    health: global___Host.Health.ValueType
    """Aggregated health of the host. If the field has default value, it is not returned in the response."""
    subnet_id: builtins.str
    """ID of the subnet that the host belongs to."""
    replication_source: builtins.str
    """Name of the host to be used as the replication source for cascading replication."""
    assign_public_ip: builtins.bool
    """Flag showing public IP assignment status to this host."""
    replica_type: global___Host.ReplicaType.ValueType
    @property
    def resources(self) -> global___Resources:
        """Resources allocated to the PostgreSQL host."""

    @property
    def services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Service]:
        """Services provided by the host."""

    @property
    def priority(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Priority of the host as a replica. Higher value means higher priority.

        The host with the highest priority is the synchronous replica. All others are asynchronous.
        The synchronous replica replaces the master when needed.

        When a replica becomes the master, its priority is ignored.
        """

    @property
    def config(self) -> global___HostConfig:
        """Configuration of a PostgreSQL server for the host."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        zone_id: builtins.str = ...,
        resources: global___Resources | None = ...,
        role: global___Host.Role.ValueType = ...,
        health: global___Host.Health.ValueType = ...,
        services: collections.abc.Iterable[global___Service] | None = ...,
        subnet_id: builtins.str = ...,
        replication_source: builtins.str = ...,
        priority: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        config: global___HostConfig | None = ...,
        assign_public_ip: builtins.bool = ...,
        replica_type: global___Host.ReplicaType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config", "priority", b"priority", "resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["assign_public_ip", b"assign_public_ip", "cluster_id", b"cluster_id", "config", b"config", "health", b"health", "name", b"name", "priority", b"priority", "replica_type", b"replica_type", "replication_source", b"replication_source", "resources", b"resources", "role", b"role", "services", b"services", "subnet_id", b"subnet_id", "zone_id", b"zone_id"]) -> None: ...

global___Host = Host

@typing.final
class HostConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POSTGRESQL_CONFIG_9_6_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_10_1C_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_10_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_11_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_11_1C_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_12_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_12_1C_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_13_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_13_1C_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_14_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_14_1C_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_15_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_15_1C_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_16_FIELD_NUMBER: builtins.int
    POSTGRESQL_CONFIG_16_1C_FIELD_NUMBER: builtins.int
    @property
    def postgresql_config_9_6(self) -> yandex.cloud.mdb.postgresql.v1.config.host9_6_pb2.PostgresqlHostConfig9_6:
        """Configuration for a host with PostgreSQL 9.6 server deployed."""

    @property
    def postgresql_config_10_1c(self) -> yandex.cloud.mdb.postgresql.v1.config.host10_1c_pb2.PostgresqlHostConfig10_1C:
        """Configuration for a host with PostgreSQL 10 1C server deployed."""

    @property
    def postgresql_config_10(self) -> yandex.cloud.mdb.postgresql.v1.config.host10_pb2.PostgresqlHostConfig10:
        """Configuration for a host with PostgreSQL 10 server deployed."""

    @property
    def postgresql_config_11(self) -> yandex.cloud.mdb.postgresql.v1.config.host11_pb2.PostgresqlHostConfig11:
        """Configuration for a host with PostgreSQL 11 server deployed."""

    @property
    def postgresql_config_11_1c(self) -> yandex.cloud.mdb.postgresql.v1.config.host11_1c_pb2.PostgresqlHostConfig11_1C:
        """Configuration for a host with PostgreSQL 11 1C server deployed."""

    @property
    def postgresql_config_12(self) -> yandex.cloud.mdb.postgresql.v1.config.host12_pb2.PostgresqlHostConfig12:
        """Configuration for a host with PostgreSQL 12 server deployed."""

    @property
    def postgresql_config_12_1c(self) -> yandex.cloud.mdb.postgresql.v1.config.host12_1c_pb2.PostgresqlHostConfig12_1C:
        """Configuration for a host with PostgreSQL 12 1C server deployed."""

    @property
    def postgresql_config_13(self) -> yandex.cloud.mdb.postgresql.v1.config.host13_pb2.PostgresqlHostConfig13:
        """Configuration for a host with PostgreSQL 13 server deployed."""

    @property
    def postgresql_config_13_1c(self) -> yandex.cloud.mdb.postgresql.v1.config.host13_1c_pb2.PostgresqlHostConfig13_1C:
        """Configuration for a host with PostgreSQL 13 1C server deployed."""

    @property
    def postgresql_config_14(self) -> yandex.cloud.mdb.postgresql.v1.config.host14_pb2.PostgresqlHostConfig14:
        """Configuration for a host with PostgreSQL 14 server deployed."""

    @property
    def postgresql_config_14_1c(self) -> yandex.cloud.mdb.postgresql.v1.config.host14_1c_pb2.PostgresqlHostConfig14_1C:
        """Configuration for a host with PostgreSQL 14 1C server deployed."""

    @property
    def postgresql_config_15(self) -> yandex.cloud.mdb.postgresql.v1.config.host15_pb2.PostgresqlHostConfig15:
        """Configuration for a host with PostgreSQL 15 server deployed."""

    @property
    def postgresql_config_15_1c(self) -> yandex.cloud.mdb.postgresql.v1.config.host15_1c_pb2.PostgresqlHostConfig15_1C:
        """Configuration for a host with PostgreSQL 15 1C server deployed."""

    @property
    def postgresql_config_16(self) -> yandex.cloud.mdb.postgresql.v1.config.host16_pb2.PostgresqlHostConfig16:
        """Configuration for a host with PostgreSQL 16 server deployed."""

    @property
    def postgresql_config_16_1c(self) -> yandex.cloud.mdb.postgresql.v1.config.host16_1c_pb2.PostgresqlHostConfig16_1C:
        """Configuration for a host with PostgreSQL 16 1C server deployed."""

    def __init__(
        self,
        *,
        postgresql_config_9_6: yandex.cloud.mdb.postgresql.v1.config.host9_6_pb2.PostgresqlHostConfig9_6 | None = ...,
        postgresql_config_10_1c: yandex.cloud.mdb.postgresql.v1.config.host10_1c_pb2.PostgresqlHostConfig10_1C | None = ...,
        postgresql_config_10: yandex.cloud.mdb.postgresql.v1.config.host10_pb2.PostgresqlHostConfig10 | None = ...,
        postgresql_config_11: yandex.cloud.mdb.postgresql.v1.config.host11_pb2.PostgresqlHostConfig11 | None = ...,
        postgresql_config_11_1c: yandex.cloud.mdb.postgresql.v1.config.host11_1c_pb2.PostgresqlHostConfig11_1C | None = ...,
        postgresql_config_12: yandex.cloud.mdb.postgresql.v1.config.host12_pb2.PostgresqlHostConfig12 | None = ...,
        postgresql_config_12_1c: yandex.cloud.mdb.postgresql.v1.config.host12_1c_pb2.PostgresqlHostConfig12_1C | None = ...,
        postgresql_config_13: yandex.cloud.mdb.postgresql.v1.config.host13_pb2.PostgresqlHostConfig13 | None = ...,
        postgresql_config_13_1c: yandex.cloud.mdb.postgresql.v1.config.host13_1c_pb2.PostgresqlHostConfig13_1C | None = ...,
        postgresql_config_14: yandex.cloud.mdb.postgresql.v1.config.host14_pb2.PostgresqlHostConfig14 | None = ...,
        postgresql_config_14_1c: yandex.cloud.mdb.postgresql.v1.config.host14_1c_pb2.PostgresqlHostConfig14_1C | None = ...,
        postgresql_config_15: yandex.cloud.mdb.postgresql.v1.config.host15_pb2.PostgresqlHostConfig15 | None = ...,
        postgresql_config_15_1c: yandex.cloud.mdb.postgresql.v1.config.host15_1c_pb2.PostgresqlHostConfig15_1C | None = ...,
        postgresql_config_16: yandex.cloud.mdb.postgresql.v1.config.host16_pb2.PostgresqlHostConfig16 | None = ...,
        postgresql_config_16_1c: yandex.cloud.mdb.postgresql.v1.config.host16_1c_pb2.PostgresqlHostConfig16_1C | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["postgresql_config", b"postgresql_config", "postgresql_config_10", b"postgresql_config_10", "postgresql_config_10_1c", b"postgresql_config_10_1c", "postgresql_config_11", b"postgresql_config_11", "postgresql_config_11_1c", b"postgresql_config_11_1c", "postgresql_config_12", b"postgresql_config_12", "postgresql_config_12_1c", b"postgresql_config_12_1c", "postgresql_config_13", b"postgresql_config_13", "postgresql_config_13_1c", b"postgresql_config_13_1c", "postgresql_config_14", b"postgresql_config_14", "postgresql_config_14_1c", b"postgresql_config_14_1c", "postgresql_config_15", b"postgresql_config_15", "postgresql_config_15_1c", b"postgresql_config_15_1c", "postgresql_config_16", b"postgresql_config_16", "postgresql_config_16_1c", b"postgresql_config_16_1c", "postgresql_config_9_6", b"postgresql_config_9_6"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["postgresql_config", b"postgresql_config", "postgresql_config_10", b"postgresql_config_10", "postgresql_config_10_1c", b"postgresql_config_10_1c", "postgresql_config_11", b"postgresql_config_11", "postgresql_config_11_1c", b"postgresql_config_11_1c", "postgresql_config_12", b"postgresql_config_12", "postgresql_config_12_1c", b"postgresql_config_12_1c", "postgresql_config_13", b"postgresql_config_13", "postgresql_config_13_1c", b"postgresql_config_13_1c", "postgresql_config_14", b"postgresql_config_14", "postgresql_config_14_1c", b"postgresql_config_14_1c", "postgresql_config_15", b"postgresql_config_15", "postgresql_config_15_1c", b"postgresql_config_15_1c", "postgresql_config_16", b"postgresql_config_16", "postgresql_config_16_1c", b"postgresql_config_16_1c", "postgresql_config_9_6", b"postgresql_config_9_6"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["postgresql_config", b"postgresql_config"]) -> typing.Literal["postgresql_config_9_6", "postgresql_config_10_1c", "postgresql_config_10", "postgresql_config_11", "postgresql_config_11_1c", "postgresql_config_12", "postgresql_config_12_1c", "postgresql_config_13", "postgresql_config_13_1c", "postgresql_config_14", "postgresql_config_14_1c", "postgresql_config_15", "postgresql_config_15_1c", "postgresql_config_16", "postgresql_config_16_1c"] | None: ...

global___HostConfig = HostConfig

@typing.final
class Service(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Service._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Service._Type.ValueType  # 0
        """Service type of the host is unspecified. Default value."""
        POSTGRESQL: Service._Type.ValueType  # 1
        """The host is a PostgreSQL server."""
        POOLER: Service._Type.ValueType  # 2
        """The host is a PgBouncer server."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: Service.Type.ValueType  # 0
    """Service type of the host is unspecified. Default value."""
    POSTGRESQL: Service.Type.ValueType  # 1
    """The host is a PostgreSQL server."""
    POOLER: Service.Type.ValueType  # 2
    """The host is a PgBouncer server."""

    class _Health:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Service._Health.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        HEALTH_UNKNOWN: Service._Health.ValueType  # 0
        """Health of the server is unknown. Default value."""
        ALIVE: Service._Health.ValueType  # 1
        """The server is working normally."""
        DEAD: Service._Health.ValueType  # 2
        """The server is dead or unresponsive."""
        READONLY: Service._Health.ValueType  # 3
        """The server is in read-only mode."""

    class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...
    HEALTH_UNKNOWN: Service.Health.ValueType  # 0
    """Health of the server is unknown. Default value."""
    ALIVE: Service.Health.ValueType  # 1
    """The server is working normally."""
    DEAD: Service.Health.ValueType  # 2
    """The server is dead or unresponsive."""
    READONLY: Service.Health.ValueType  # 3
    """The server is in read-only mode."""

    TYPE_FIELD_NUMBER: builtins.int
    HEALTH_FIELD_NUMBER: builtins.int
    type: global___Service.Type.ValueType
    """Type of the service provided by the host. If the field has default value, it is not returned in the response."""
    health: global___Service.Health.ValueType
    """Aggregated health of the service. If the field has default value, it is not returned in the response."""
    def __init__(
        self,
        *,
        type: global___Service.Type.ValueType = ...,
        health: global___Service.Health.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["health", b"health", "type", b"type"]) -> None: ...

global___Service = Service

@typing.final
class Resources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    DISK_TYPE_ID_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    """ID of the preset for computational resources available to a host (CPU, memory etc.).
    All available presets are listed in the [documentation](/docs/managed-postgresql/concepts/instance-types).
    """
    disk_size: builtins.int
    """Volume of the storage available to a host, in bytes."""
    disk_type_id: builtins.str
    """Type of the storage environment for the host.
    Possible values:
    * network-hdd - network HDD drive,
    * network-ssd - network SSD drive,
    * local-ssd - local SSD storage.
    """
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
        disk_size: builtins.int = ...,
        disk_type_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_size", b"disk_size", "disk_type_id", b"disk_type_id", "resource_preset_id", b"resource_preset_id"]) -> None: ...

global___Resources = Resources

@typing.final
class Access(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_LENS_FIELD_NUMBER: builtins.int
    WEB_SQL_FIELD_NUMBER: builtins.int
    SERVERLESS_FIELD_NUMBER: builtins.int
    DATA_TRANSFER_FIELD_NUMBER: builtins.int
    YANDEX_QUERY_FIELD_NUMBER: builtins.int
    data_lens: builtins.bool
    """Allow access for DataLens"""
    web_sql: builtins.bool
    """Allow SQL queries to the cluster databases from the management console.

    See [SQL queries in the management console](/docs/managed-postgresql/operations/web-sql-query) for more details.
    """
    serverless: builtins.bool
    """Allow access for Serverless"""
    data_transfer: builtins.bool
    """Allow access for DataTransfer."""
    yandex_query: builtins.bool
    """Allow access for YandexQuery."""
    def __init__(
        self,
        *,
        data_lens: builtins.bool = ...,
        web_sql: builtins.bool = ...,
        serverless: builtins.bool = ...,
        data_transfer: builtins.bool = ...,
        yandex_query: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["data_lens", b"data_lens", "data_transfer", b"data_transfer", "serverless", b"serverless", "web_sql", b"web_sql", "yandex_query", b"yandex_query"]) -> None: ...

global___Access = Access

@typing.final
class PerformanceDiagnostics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    SESSIONS_SAMPLING_INTERVAL_FIELD_NUMBER: builtins.int
    STATEMENTS_SAMPLING_INTERVAL_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    """Configuration setting which enables/disables performance diagnostics service in cluster."""
    sessions_sampling_interval: builtins.int
    """Interval (in seconds) for pg_stat_activity sampling"""
    statements_sampling_interval: builtins.int
    """Interval (in seconds) for pg_stat_statements sampling"""
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        sessions_sampling_interval: builtins.int = ...,
        statements_sampling_interval: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "sessions_sampling_interval", b"sessions_sampling_interval", "statements_sampling_interval", b"statements_sampling_interval"]) -> None: ...

global___PerformanceDiagnostics = PerformanceDiagnostics

@typing.final
class DiskSizeAutoscaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLANNED_USAGE_THRESHOLD_FIELD_NUMBER: builtins.int
    EMERGENCY_USAGE_THRESHOLD_FIELD_NUMBER: builtins.int
    DISK_SIZE_LIMIT_FIELD_NUMBER: builtins.int
    planned_usage_threshold: builtins.int
    """Threshold of storage usage (in percent) that triggers automatic scaling of the storage during the maintenance window. Zero value means disabled threshold."""
    emergency_usage_threshold: builtins.int
    """Threshold of storage usage (in percent) that triggers immediate automatic scaling of the storage. Zero value means disabled threshold."""
    disk_size_limit: builtins.int
    """New storage size (in bytes) that is set when one of the thresholds is achieved."""
    def __init__(
        self,
        *,
        planned_usage_threshold: builtins.int = ...,
        emergency_usage_threshold: builtins.int = ...,
        disk_size_limit: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_size_limit", b"disk_size_limit", "emergency_usage_threshold", b"emergency_usage_threshold", "planned_usage_threshold", b"planned_usage_threshold"]) -> None: ...

global___DiskSizeAutoscaling = DiskSizeAutoscaling



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.billing.v1.billing_account_pb2
import yandex.cloud.billing.v1.billing_account_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class BillingAccountServiceStub:
    """A set of methods for managing BillingAccount resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.billing_account_service_pb2.GetBillingAccountRequest,
        yandex.cloud.billing.v1.billing_account_pb2.BillingAccount,
    ]
    """Returns the specified billing account."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.billing_account_service_pb2.ListBillingAccountsRequest,
        yandex.cloud.billing.v1.billing_account_service_pb2.ListBillingAccountsResponse,
    ]
    """Retrieves the list of billing accounts available for current user."""

    ListBillableObjectBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.billing_account_service_pb2.ListBillableObjectBindingsRequest,
        yandex.cloud.billing.v1.billing_account_service_pb2.ListBillableObjectBindingsResponse,
    ]
    """Retrieves the list of billable object bindings associated with the specified billing account."""

    BindBillableObject: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.billing_account_service_pb2.BindBillableObjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Binds billable object to the specified billing account."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists access bindings for the specified billing account."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified billing account."""

class BillingAccountServiceAsyncStub:
    """A set of methods for managing BillingAccount resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.billing_account_service_pb2.GetBillingAccountRequest,
        yandex.cloud.billing.v1.billing_account_pb2.BillingAccount,
    ]
    """Returns the specified billing account."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.billing_account_service_pb2.ListBillingAccountsRequest,
        yandex.cloud.billing.v1.billing_account_service_pb2.ListBillingAccountsResponse,
    ]
    """Retrieves the list of billing accounts available for current user."""

    ListBillableObjectBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.billing_account_service_pb2.ListBillableObjectBindingsRequest,
        yandex.cloud.billing.v1.billing_account_service_pb2.ListBillableObjectBindingsResponse,
    ]
    """Retrieves the list of billable object bindings associated with the specified billing account."""

    BindBillableObject: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.billing.v1.billing_account_service_pb2.BindBillableObjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Binds billable object to the specified billing account."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists access bindings for the specified billing account."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified billing account."""

class BillingAccountServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing BillingAccount resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.billing.v1.billing_account_service_pb2.GetBillingAccountRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.billing.v1.billing_account_pb2.BillingAccount, collections.abc.Awaitable[yandex.cloud.billing.v1.billing_account_pb2.BillingAccount]]:
        """Returns the specified billing account."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.billing.v1.billing_account_service_pb2.ListBillingAccountsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.billing.v1.billing_account_service_pb2.ListBillingAccountsResponse, collections.abc.Awaitable[yandex.cloud.billing.v1.billing_account_service_pb2.ListBillingAccountsResponse]]:
        """Retrieves the list of billing accounts available for current user."""

    @abc.abstractmethod
    def ListBillableObjectBindings(
        self,
        request: yandex.cloud.billing.v1.billing_account_service_pb2.ListBillableObjectBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.billing.v1.billing_account_service_pb2.ListBillableObjectBindingsResponse, collections.abc.Awaitable[yandex.cloud.billing.v1.billing_account_service_pb2.ListBillableObjectBindingsResponse]]:
        """Retrieves the list of billable object bindings associated with the specified billing account."""

    @abc.abstractmethod
    def BindBillableObject(
        self,
        request: yandex.cloud.billing.v1.billing_account_service_pb2.BindBillableObjectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Binds billable object to the specified billing account."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """Lists access bindings for the specified billing account."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the specified billing account."""

def add_BillingAccountServiceServicer_to_server(servicer: BillingAccountServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.loadtesting.api.v1.report.kpi_pb2
import yandex.cloud.loadtesting.api.v1.report.kpi_value_pb2
import yandex.cloud.loadtesting.api.v1.report.status_pb2
import yandex.cloud.loadtesting.api.v1.report.table.report_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetTableReportRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEST_ID_FIELD_NUMBER: builtins.int
    test_id: builtins.str
    """ID of the test for which report table will be returned."""
    def __init__(
        self,
        *,
        test_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["test_id", b"test_id"]) -> None: ...

global___GetTableReportRequest = GetTableReportRequest

@typing.final
class GetTableReportResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class CasesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> yandex.cloud.loadtesting.api.v1.report.table.report_pb2.Report: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: yandex.cloud.loadtesting.api.v1.report.table.report_pb2.Report | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    STATUS_FIELD_NUMBER: builtins.int
    OVERALL_FIELD_NUMBER: builtins.int
    CASES_FIELD_NUMBER: builtins.int
    status: yandex.cloud.loadtesting.api.v1.report.status_pb2.Status.ValueType
    """Status of report table."""
    @property
    def overall(self) -> yandex.cloud.loadtesting.api.v1.report.table.report_pb2.Report:
        """Result for all test cases combined ("overall" test case)."""

    @property
    def cases(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, yandex.cloud.loadtesting.api.v1.report.table.report_pb2.Report]:
        """Results for individual test cases, mapped as `case_name:report`."""

    def __init__(
        self,
        *,
        status: yandex.cloud.loadtesting.api.v1.report.status_pb2.Status.ValueType = ...,
        overall: yandex.cloud.loadtesting.api.v1.report.table.report_pb2.Report | None = ...,
        cases: collections.abc.Mapping[builtins.str, yandex.cloud.loadtesting.api.v1.report.table.report_pb2.Report] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["overall", b"overall"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cases", b"cases", "overall", b"overall", "status", b"status"]) -> None: ...

global___GetTableReportResponse = GetTableReportResponse

@typing.final
class CalculateReportKpiValuesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    TEST_FILTER_FIELD_NUMBER: builtins.int
    TEST_CASE_FIELD_NUMBER: builtins.int
    KPI_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder containing tests."""
    test_filter: builtins.str
    """Test filter selector to calculate KPI values for."""
    test_case: builtins.str
    """Test case to calculate KPI values for.

    If not specified, KPI values will be calculated for 'overall' case.
    """
    @property
    def kpi(self) -> yandex.cloud.loadtesting.api.v1.report.kpi_pb2.Kpi:
        """KPI to be calculated."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        test_filter: builtins.str = ...,
        test_case: builtins.str = ...,
        kpi: yandex.cloud.loadtesting.api.v1.report.kpi_pb2.Kpi | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["kpi", b"kpi"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "kpi", b"kpi", "test_case", b"test_case", "test_filter", b"test_filter"]) -> None: ...

global___CalculateReportKpiValuesRequest = CalculateReportKpiValuesRequest

@typing.final
class CalculateReportKpiValuesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder."""
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.loadtesting.api.v1.report.kpi_value_pb2.KpiValue]:
        """Actual KPI values."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        values: collections.abc.Iterable[yandex.cloud.loadtesting.api.v1.report.kpi_value_pb2.KpiValue] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "values", b"values"]) -> None: ...

global___CalculateReportKpiValuesResponse = CalculateReportKpiValuesResponse
